// not using lite versions on server because on client we favor using full firestore cache-first versions instead of a fetch request on every data request (which count as a read even when a user hovers over a link with sveltekite:prefetch for example) and server and client must be using both lite or both regular firestore otherwise we will have errors when trying to pass in queryConstraints from the opposite package.
import { getFirestore, collection, doc, getDocs, getDoc, query, } from 'firebase/firestore/lite';
export function colRef(ref, firebaseApp) {
    const db = getFirestore(firebaseApp);
    return typeof ref === 'string' ? collection(db, ref) : ref;
}
export function docRef(ref, firebaseApp) {
    if (typeof ref === 'string') {
        const pathParts = ref.split('/');
        const documentId = pathParts.pop();
        const collectionString = pathParts.join('/');
        return doc(colRef(collectionString, firebaseApp), documentId);
    }
    else {
        return ref;
    }
}
export async function getCollection(path, queryConstraints = [], firebaseApp) {
    const ref = typeof path === 'string' ? colRef(path, firebaseApp) : path;
    const q = query(ref, ...queryConstraints);
    const collectionSnap = await getDocs(q);
    return collectionSnap.docs.map((docSnap) => ({
        ...docSnap.data(),
        id: docSnap.id,
    }));
}
export async function getDocument(ref, firebaseApp) {
    const docSnap = await getDoc(docRef(ref, firebaseApp));
    return docSnap.exists() ? { ...docSnap.data(), id: docSnap.id } : null;
}
